@@ -184,8 +184,7 @@ intervene <- function(scc, causes = NULL, intervention = NULL, output = c("nice"
       checkmate::assert_data_frame(out_table$minimal, any.missing = F, null.ok = F)
       checkmate::assert_list(out_table$order, types = "list")
       checkmate::assert_list(out_table$order[[1]], types = c("logical","data.frame"))
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                              parent = cnd, class = "output")
     })
     #=============================================================================
@@ -220,22 +219,19 @@ intervene <- function(scc, causes = NULL, intervention = NULL, output = c("nice"
 get_intv <- function(scc, intervention, split) {
   # Check input
   if (inherits(scc, "epicmodel_scc") %>% magrittr::not()) {
-    cli::cli_abort(c("Input validation error: {.var scc}",
-                     "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"), class = "input_scc")
+    cli::cli_abort("Input validation error: {.var scc}", .internal = TRUE, class = "input_scc")
   }
 
   rlang::try_fetch({
       checkmate::assert_character(intervention, any.missing = F, null.ok = T, min.len = 1, min.chars = 1)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var intervention}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var intervention}", .internal = TRUE,
                                              parent = cnd, class = "input_intervention")
   })
 
   rlang::try_fetch({
       checkmate::assert_list(split, any.missing = F, null.ok = F, len = 5, names = "unique")
       checkmate::assert_subset(names(split), c("non_start_steps","causes","interventions","ifnot_steps","end_steps"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var split}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var split}", .internal = TRUE,
                                              parent = cnd, class = "input_split")
   })
   #=============================================================================
@@ -279,7 +275,7 @@ get_intv <- function(scc, intervention, split) {
         intv <- grid
       } else {
         ## Check if specified interventions exists
-        if (intervention %>% magrittr::is_in(split$interventions$id_step) %>% all_true() %>% magrittr::not()) {
+        if (intervention %>% magrittr::is_in(split$interventions$id_step) %>% all() %>% magrittr::not()) {
           cli::cli_abort(c("All elements of {.var intervention} must be IDs of valid intervention steps!",
                            "i" = "Run {.fn intervene} without {.var intervention} argument to list all available intervention steps."),
                          class = "invalid_interventions")
@@ -292,12 +288,12 @@ get_intv <- function(scc, intervention, split) {
     } else {
       # With multiple intervetions specified
       ## Check if "all" has been specified as one element of the vector
-      if (intervention %>% magrittr::is_in("all") %>% all_false() %>% magrittr::not()) {
+      if (intervention %>% magrittr::is_in("all") %>% any()) {
         cli::cli_abort("In {.var intervention}, option {.field 'all'} can only be specified on its own without any other elements!",
                        class = "invalid_interventions_all")
       }
       ## Check if selected interventions exist
-      if (intervention %>% magrittr::is_in(split$interventions$id_step) %>% all_true() %>% magrittr::not()) {
+      if (intervention %>% magrittr::is_in(split$interventions$id_step) %>% all() %>% magrittr::not()) {
         invalid_intv <- intervention[intervention %>% magrittr::is_in(split$interventions$id_step) %>% magrittr::not()] %>%
           stringr::str_c(collapse = ", ")
         cli::cli_abort(c("All elements of {.var intervention} must be IDs of valid intervention steps!",
@@ -334,8 +330,7 @@ get_intv <- function(scc, intervention, split) {
                                    col.names = "unique")
       checkmate::assert_character(rownames(intv), pattern = "^intv[[:digit:]]+$")
       checkmate::assert_set_equal(colnames(intv), split$interventions$id_step)
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                              parent = cnd, class = "output")
   })
   #=============================================================================
@@ -363,22 +358,19 @@ get_intv <- function(scc, intervention, split) {
 get_causes <- function(scc, causes, split) {
   # Check input
   if (inherits(scc, "epicmodel_scc") %>% magrittr::not()) {
-    cli::cli_abort(c("Input validation error: {.var scc}",
-                     "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"), class = "input_scc")
+    cli::cli_abort("Input validation error: {.var scc}", .internal = TRUE, class = "input_scc")
   }
 
   rlang::try_fetch({
       checkmate::assert_character(causes, any.missing = F, null.ok = T, min.len = 1, min.chars = 1)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var causes}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var causes}", .internal = TRUE,
                                              parent = cnd, class = "input_causes")
   })
 
   rlang::try_fetch({
       checkmate::assert_list(split, any.missing = F, null.ok = F, len = 5, names = "unique")
       checkmate::assert_subset(names(split), c("non_start_steps","causes","interventions","ifnot_steps","end_steps"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var split}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var split}", .internal = TRUE,
                                              parent = cnd, class = "input_split")
   })
   #=============================================================================
@@ -401,7 +393,7 @@ get_causes <- function(scc, causes, split) {
         cause_set <- scc$sc_cc
       } else {
         ## Check if specified cause exists
-        if (causes %>% magrittr::is_in(split$causes$id_step) %>% all_true() %>% magrittr::not()) {
+        if (causes %>% magrittr::is_in(split$causes$id_step) %>% all() %>% magrittr::not()) {
           cli::cli_abort(c("All elements of {.var causes} must be IDs of valid component causes!",
                            "i" = "Run {.fn intervene} without {.var causes} argument to list all available component causes."),
                          class = "invalid_causes")
@@ -421,12 +413,12 @@ get_causes <- function(scc, causes, split) {
     } else {
       # With multiple causes specified
       ## Check if "all" has been specified as one element of the vector
-      if (causes %>% magrittr::is_in("all") %>% all_false() %>% magrittr::not()) {
+      if (causes %>% magrittr::is_in("all") %>% any()) {
         cli::cli_abort("In {.var causes}, option {.field 'all'} can only be specified on its own without any other elements!",
                        class = "invalid_causes_all")
       }
       ## Check if selected causes exist
-      if (causes %>% magrittr::is_in(split$causes$id_step) %>% all_true() %>% magrittr::not()) {
+      if (causes %>% magrittr::is_in(split$causes$id_step) %>% all() %>% magrittr::not()) {
         invalid_causes <- causes[causes %>% magrittr::is_in(split$causes$id_step) %>% magrittr::not()] %>%
           stringr::str_c(collapse = ", ")
         cli::cli_abort(c("All elements of {.var causes} must be IDs of valid component causes!",
@@ -448,7 +440,7 @@ get_causes <- function(scc, causes, split) {
               icc_check$check[i] <- TRUE
             }
           }
-          if (icc_check$check %>% all_false() %>% magrittr::not()) {
+          if (icc_check$check %>% any()) {
             icc_check$combi_desc <- paste(icc_check$desc1," <> ",icc_check$desc2)
             icc_causes <- icc_check %>% dplyr::filter(.data$check == TRUE) %>% magrittr::extract2("combi_desc") %>%
               stringr::str_c(collapse = ", ")
@@ -472,8 +464,7 @@ get_causes <- function(scc, causes, split) {
                                    col.names = "unique")
       checkmate::assert_character(rownames(cause_set), pattern = "^cc[[:digit:]]+$")
       checkmate::assert_set_equal(colnames(cause_set), split$causes$id_step)
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                              parent = cnd, class = "output")
   })
   #=============================================================================
@@ -498,15 +489,13 @@ get_prevented_causes <- function(causes, intv) {
       checkmate::assert_tibble(causes, null.ok = F, ncols = 12, min.rows = 1, col.names = "unique")
       checkmate::assert_subset(colnames(causes), c("id_step","then_step","subject_step","does_step","object_step","where_step","if_step","if_list",
                                                 "ifnot_step","ifnot_list","end_step","module_step"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var causes}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var causes}", .internal = TRUE,
                                              parent = cnd, class = "input_causes")
   })
 
   rlang::try_fetch({
       checkmate::assert_character(intv, any.missing = F, null.ok = F, min.chars = 1, min.len = 1, unique = TRUE)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var intv}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var intv}", .internal = TRUE,
                                              parent = cnd, class = "input_intv")
   })
   #=============================================================================
@@ -528,7 +517,7 @@ get_prevented_causes <- function(causes, intv) {
                                           current_list_then = intv %>% sep_step() %>% magrittr::extract2("then"))
     }
     ## No IFNOT condition is fulfilled
-    if (fulfilled_causes %>% all_false()) {
+    if (fulfilled_causes %>% any() %>% magrittr::not()) {
       return(character(0))
     } else {
     ## Some IFNOT conditions are fulfilled
@@ -538,8 +527,7 @@ get_prevented_causes <- function(causes, intv) {
       rlang::try_fetch({
           checkmate::assert_character(out, any.missing = F, null.ok = F, min.chars = 1, min.len = 1, unique = TRUE)
           checkmate::assert_subset(out, causes$id_step, empty.ok = F)
-        }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                                 "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+        }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                                  parent = cnd, class = "output")
       })
       #=============================================================================
@@ -566,15 +554,13 @@ get_prevented_non_start_steps <- function(non_start_steps, intv) {
       checkmate::assert_tibble(non_start_steps, null.ok = F, ncols = 12, col.names = "unique")
       checkmate::assert_subset(colnames(non_start_steps), c("id_step","then_step","subject_step","does_step","object_step","where_step","if_step",
                                                             "if_list","ifnot_step","ifnot_list","end_step","module_step"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var non_start_steps}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var non_start_steps}", .internal = TRUE,
                                              parent = cnd, class = "input_non_start_steps")
   })
 
   rlang::try_fetch({
       checkmate::assert_character(intv, any.missing = F, null.ok = F, min.chars = 1, min.len = 1, unique = TRUE)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var intv}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var intv}", .internal = TRUE,
                                              parent = cnd, class = "input_intv")
   })
   #=============================================================================
@@ -596,7 +582,7 @@ get_prevented_non_start_steps <- function(non_start_steps, intv) {
                                           current_list_then = intv %>% sep_step() %>% magrittr::extract2("then"))
     }
     ## No IFNOT condition is fulfilled
-    if (fulfilled_steps %>% all_false()) {
+    if (fulfilled_steps %>% any() %>% magrittr::not()) {
       return(character(0))
     } else {
       ## Some IFNOT conditions are fulfilled
@@ -606,8 +592,7 @@ get_prevented_non_start_steps <- function(non_start_steps, intv) {
       rlang::try_fetch({
           checkmate::assert_character(out, any.missing = F, null.ok = F, min.chars = 1, min.len = 1, unique = TRUE)
           checkmate::assert_subset(out, non_start_steps$id_step, empty.ok = F)
-        }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                                 "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+        }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                                  parent = cnd, class = "output")
       })
       #=============================================================================
@@ -647,15 +632,13 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
                                    col.names = "unique")
       checkmate::assert_character(rownames(cause_set), pattern = "^cc[[:digit:]]+$")
       checkmate::assert_set_equal(colnames(cause_set), split$causes$id_step)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var cause_set}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var cause_set}", .internal = TRUE,
                                              parent = cnd, class = "input_cause_set")
   })
 
   rlang::try_fetch({
       checkmate::assert_character(intv, any.missing = F, null.ok = F, min.len = 1, min.chars = 1)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var intv}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var intv}", .internal = TRUE,
                                              parent = cnd, class = "input_intv")
   })
 
@@ -663,16 +646,14 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
       checkmate::assert_tibble(prc, null.ok = F, ncols = 12, min.rows = 1, col.names = "unique")
       checkmate::assert_subset(colnames(prc), c("id_step","then_step","subject_step","does_step","object_step","where_step","if_step","if_list",
                                                 "ifnot_step","ifnot_list","end_step","module_step"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var prc}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var prc}", .internal = TRUE,
                                              parent = cnd, class = "input_prc")
   })
 
   rlang::try_fetch({
       checkmate::assert_list(split, any.missing = F, null.ok = F, len = 5, names = "unique")
       checkmate::assert_subset(names(split), c("non_start_steps","causes","interventions","ifnot_steps","end_steps"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var split}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var split}", .internal = TRUE,
                                              parent = cnd, class = "input_split")
   })
 
@@ -682,8 +663,7 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
       checkmate::assert_subset(colnames(outc_list), c("sce","id"), empty.ok = F)
       checkmate::assert_integerish(outc_list$sce %>% as.numeric(), lower = 1, any.missing = F, null.ok = F)
       checkmate::assert_subset(outc_list$id, end_then, empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error", .internal = TRUE,
                                              parent = cnd, class = "input_outc_list")
   })
   #=============================================================================
@@ -704,7 +684,7 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
 
   # Check sufficiency
   ## Check if all component causes are FALSE
-  if (cause_set %>% as.logical() %>% all_false()) {
+  if (cause_set %>% as.logical() %>% any() %>% magrittr::not()) {
     sufficient <- FALSE
     final_steps <- character(0)
   } else {
@@ -752,24 +732,21 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
   rlang::try_fetch({
       checkmate::assert_list(out, types = c("data.frame","logical","character"), null.ok = F, len = 2, names = "unique")
       checkmate::assert_set_equal(names(out), c("intv_status","intv_order"), ordered = T)
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error: {.var out}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error: {.var out}", .internal = TRUE,
                                              parent = cnd, class = "output_out")
   })
 
   rlang::try_fetch({
     checkmate::assert_character(out$intv_status, any.missing = F, null.ok = F, len = 1, min.chars = 1)
     checkmate::assert_choice(out$intv_status, c("always", "never", "depends"))
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error: {.var out$intv_status}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error: {.var out$intv_status}", .internal = TRUE,
                                              parent = cnd, class = "output_out$intv_status")
   })
 
-  if (is.na(out$intv_order) %>% all_true()) {
+  if (is.na(out$intv_order) %>% all()) {
     rlang::try_fetch({
       checkmate::assert_scalar_na(out$intv_order, null.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error: {.var out$intv_order}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error: {.var out$intv_order}", .internal = TRUE,
                                              parent = cnd, class = "output_out$intv_order")
     })
   } else {
@@ -779,8 +756,7 @@ check_causes_x_intv <- function(scc, cause_set, intv, prc, split, outc_list) {
       checkmate::assert_set_equal(colnames(out$intv_order), c("order", "suff"), ordered = T)
       checkmate::assert_logical(out$intv_order$suff, any.missing = F, null.ok = F)
       checkmate::assert_character(out$intv_order$order, any.missing = F, null.ok = F, min.chars = 1, unique = T)
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error: {.var out$intv_order}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error: {.var out$intv_order}", .internal = TRUE,
                                              parent = cnd, class = "output_out$intv_order")
     })
   }
@@ -822,8 +798,7 @@ minimize_intv <- function(intv, out_status) {
       checkmate::assert_data_frame(intv, any.missing = F, null.ok = F, types = "logical", min.rows = 1, min.cols = 1, row.names = "unique",
                                    col.names = "unique")
       checkmate::assert_character(rownames(intv), pattern = "^intv[[:digit:]]+$")
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var intv}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var intv}", .internal = TRUE,
                                              parent = cnd, class = "input_intv")
   })
 
@@ -832,8 +807,7 @@ minimize_intv <- function(intv, out_status) {
                                    col.names = "unique")
       checkmate::assert_character(colnames(out_status), pattern = "^intv[[:digit:]]+$")
       checkmate::assert_character(rownames(out_status), pattern = "^cc[[:digit:]]+$")
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var out_status}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var out_status}", .internal = TRUE,
                                              parent = cnd, class = "input_out_status")
   })
   #=============================================================================
@@ -847,7 +821,7 @@ minimize_intv <- function(intv, out_status) {
     intv0_status <- out_status[i,"intv0"]
     # LEGACY: intv_all_status <- out_status[i, c(2:ncol(out_status))]
     intv_all_status <- out_status %>% dplyr::select(2:dplyr::last_col()) %>% dplyr::slice(i)
-    never_exists <- "never" %>% magrittr::equals(intv_all_status) %>% all_false() %>% magrittr::not()
+    never_exists <- "never" %>% magrittr::equals(intv_all_status) %>% any()
     never_which <- colnames(intv_all_status)["never" %>% magrittr::equals(intv_all_status)]
     depends_which <- colnames(intv_all_status)["depends" %>% magrittr::equals(intv_all_status)]
 
@@ -878,7 +852,7 @@ minimize_intv <- function(intv, out_status) {
         for (k in 1:n_rows) {
           ### Check if the component causes that are missing in the j-th set, are also missing in the k-th set
           if (length(left_out_start) > 0) {
-            also_false <- intv_temp[k,left_out_start] %>% as.logical() %>% all_false()
+            also_false <- intv_temp[k,left_out_start] %>% as.logical() %>% any() %>% magrittr::not()
           } else {
             also_false <- T
           }
@@ -901,8 +875,7 @@ minimize_intv <- function(intv, out_status) {
                                    col.names = "unique")
       checkmate::assert_character(colnames(mini), pattern = "^intv[[:digit:]]+$")
       checkmate::assert_character(rownames(mini), pattern = "^cc[[:digit:]]+$")
-    }, error = function(cnd) {cli::cli_abort(c("Output validation error",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Output validation error", .internal = TRUE,
                                              parent = cnd, class = "output")
   })
   #=============================================================================
@@ -930,8 +903,7 @@ nice_output_intervene <- function(out_table, scc, split) {
   rlang::try_fetch({
       checkmate::assert_list(split, any.missing = F, null.ok = F, len = 5, names = "unique")
       checkmate::assert_subset(names(split), c("non_start_steps","causes","interventions","ifnot_steps","end_steps"), empty.ok = F)
-    }, error = function(cnd) {cli::cli_abort(c("Input validation error: {.var split}",
-                                               "i" = "The cause is probably a bug in the {.pkg epicmodel} package. Please report it on github!"),
+    }, error = function(cnd) {cli::cli_abort("Input validation error: {.var split}", .internal = TRUE,
                                              parent = cnd, class = "input_split")
   })
   #=============================================================================
@@ -947,7 +919,7 @@ nice_output_intervene <- function(out_table, scc, split) {
     causes_temp <- out_table$cause_set[[rownames(out_table$status)[i]]]
     minimal_temp <- colnames(out_table$minimal)[out_table$minimal[i,] %>% t() %>% magrittr::extract(,1)]
     if (length(minimal_temp) > 0) {
-      never_exists_temp <- "never" %>% magrittr::equals(out_table$status[i,minimal_temp]) %>% all_false() %>% magrittr::not()
+      never_exists_temp <- "never" %>% magrittr::equals(out_table$status[i,minimal_temp]) %>% any()
       intv_temp <- vector(mode = "list", length = length(minimal_temp)) %>% magrittr::set_names(minimal_temp)
       for (j in 1:length(intv_temp)) {
         intv_temp[[j]] <- out_table$intv[[names(intv_temp)[j]]]
@@ -983,7 +955,7 @@ nice_output_intervene <- function(out_table, scc, split) {
             cat("\n")
             cli::cli_text("Prevention (no sufficiency) for the following orders of occurrence")
             order_tab <- out_table$order[[minimal_temp[j]]][[rownames(out_table$status)[i]]]
-            if (order_tab %>% is.na() %>% all_true() %>% magrittr::not()) {
+            if (order_tab %>% is.na() %>% all() %>% magrittr::not()) {
               ## Choose sufficient == FALSE because those are the orders of occurrence for which the outcome is prevented by the intervention
               cli::cli_ul(sufficient_order(order_tab, scc$steplist, sufficient = FALSE))
             }
